@@ -1,4 +1,4 @@
-# $Id: install.py 1466 2016-03-14 13:58:49Z mwall $
+# $Id: install.py 1467 2016-03-14 15:36:18Z mwall $
 # installer for the forecast extension
 # Copyright 2014-2016 Matthew Wall
 
@@ -10,7 +10,7 @@ def loader():
 class ForecastInstaller(ExtensionInstaller):
     def __init__(self):
         super(ForecastInstaller, self).__init__(
-            version="3.1.2",
+            version="3.1.3",
             name='forecast',
             description='Generate and display weather and tide forecasts.',
             author="Matthew Wall",
@@ -58,6 +58,9 @@ class ForecastInstaller(ExtensionInstaller):
                         'HTML_ROOT': 'forecast'}}},
             files=[('bin/user',
                     ['bin/user/forecast.py']),
+                   ('skins/compare',
+                    ['skins/compare/skin.conf',
+                     'skins/compare/index.html.tmpl']),
                    ('skins/forecast',
                     ['skins/forecast/skin.conf',
                      'skins/forecast/forecast_table.inc',
